@@ -1,5 +1,6 @@
 import tensorflow as tf
 import numpy as np
+import os
 from .textPreprocessing.preprocess_text import preprocess_text
 from .navec_vectorizer_layer import get_navec_word_vectorizer
 from .dev.utils.vectorize_sentence import make_sentence_vectorizer
@@ -7,7 +8,7 @@ from .dev.utils.vectorize_sentence import make_sentence_vectorizer
 
 class ToxicCommentsDetector:
     def __init__(self):
-        self.model = tf.keras.models.load_model('weightedCNN_NavecWordEmbeddings')
+        self.model = tf.keras.models.load_model(f'{os.path.dirname(__file__)}/weightedCNN_NavecWordEmbeddings')
         self.sentenceVectorizer = make_sentence_vectorizer(
             vectorizer=get_navec_word_vectorizer()[0],
             pad_sentence_to_n_words=31
@@ -18,10 +19,4 @@ class ToxicCommentsDetector:
             list(map(lambda text: self.sentenceVectorizer(preprocess_text(text)), raw_texts))
         )
 
-        return self.model.predict(preprocessed_texts)
-
-
-test_raw_texts = ['ты чего берега попутал?', 'это правый берег реки, не путай с левым']
-
-toxicDetector = ToxicCommentsDetector()
-print(toxicDetector.predict(test_raw_texts))
\ No newline at end of file
+        return self.model.predict(preprocessed_texts).flatten()
